# Cursor IDE 가이드

![Cursor IDE](https://assets.cursor.sh/img/hero.png)

Cursor IDE는 AI를 활용한 코딩 경험을 제공하는 차세대 코드 에디터입니다. 이 가이드는 Cursor IDE의 핵심 기능, 설정 방법, 사용 팁, 규칙 및 고급 기능을 소개합니다.

## 목차

- [주요 기능](#주요-기능)
- [설정 가이드](#설정-가이드)
- [사용 팁](#사용-팁)
- [규칙 가이드](#규칙-가이드)
- [고급 기능](#고급-기능)
- [Model Context Protocol (MCP)](#model-context-protocol-mcp)

## 주요 기능

Cursor IDE는 다음과 같은 핵심 기능을 제공합니다:

- **AI 기반 코드 완성**: 단순한 코드 스니펫이 아닌 고급 자동 완성 시스템
- **페어 프로그래밍**: AI가 개발자 옆에서 함께 코딩하는 듯한 경험 제공
- **지능적 다중 줄 수정**: 여러 줄에 걸친 코드 수정 및 리팩토링 가능
- **문맥 인식**: 최근 변경사항 기록, 린터 오류 고려, 현재 작업 목표 이해
- **차이 기반 UI**: 코드 변경사항을 차이 팝업으로 시각화

### GitHub Copilot과의 차이점

Cursor Tab은 GitHub Copilot과 달리 기존 코드를 수정하고, 함수를 리팩토링하며, 버그를 수정하는 능력이 있습니다. 또한 채팅 기능과 코드 분석 도구가 통합되어 있으며, 프로젝트 구조를 시각화할 수 있습니다.

## 설정 가이드

### 기본 설정

- **테마**: 다크/라이트 모드 선택
- **폰트**: 코드 폰트 및 크기 설정
- **줄 번호**: 줄 번호 표시 여부
- **자동 들여쓰기**: 자동 들여쓰기 활성화/비활성화

### AI 관련 설정

- **AI 모델**: GPT-4o, Claude 3 Opus, Claude 3 Sonnet 등 선택
- **제안 빈도**: AI 제안 표시 빈도 조절
- **컨텍스트 크기**: AI가 참조할 코드 컨텍스트 크기 설정
- **자동 완성**: 자동 완성 기능 활성화/비활성화

### 단축키 설정

- **Tab**: AI 제안 수락
- **Esc**: AI 제안 거부
- **Ctrl/⌘ + →**: 부분 수락
- **Cmd/Ctrl+L**: 채팅
- **Cmd/Ctrl+K**: 인라인 편집

## 사용 팁

### 생산성 향상

- Tab 완성, 채팅, 인라인 편집 등 AI 기능 적극 활용
- 자주 사용하는 단축키 익히기
- 개인 작업 스타일에 맞게 설정 조정
- 대규모 프로젝트에서 전체 코드베이스 컨텍스트 활용

### 문제 해결

- AI가 제안한 코드는 항상 검토
- AI가 더 정확한 제안을 할 수 있도록 충분한 컨텍스트 제공
- 문제 발생 시 관련 설정 확인 및 조정
- 특정 문제 해결에 적합한 AI 모델로 전환

## 규칙 가이드

Cursor에는 다양한 규칙 가이드가 있습니다:

1. **코드 스타일 규칙**: 자동 포맷팅, 들여쓰기, 줄 바꿈 규칙
2. **AI 제안 규칙**: 제안 우선순위, 필터링, 제한
3. **협업 규칙**: 버전 관리, 코드 리뷰, 문서화
4. **보안 규칙**: 코드 보안, AI 사용 제한, 접근 제어
5. **성능 규칙**: 리소스 사용, 캐시 관리, 최적화 규칙

## 고급 기능

### VSCode 연동

- VSCode의 확장 프로그램 사용 가능
- Cursor Settings > General > Account에서 설정
- 기존 VSCode 워크플로우 유지 가능

### 노트패드 기능 (베타)

- `Ctrl + i` (맥: `Cmd + i`)로 접근
- 노트 생성 및 관리, AI 프롬프트와 연동
- 컨텍스트 추적, 코드 스니펫 저장, 프로젝트 문서화

### 프로젝트 분석

- 코드 의존성 분석
- 아키텍처 시각화
- 성능 병목 지점 식별
- 보안 취약점 검사

### 프라이버시 설정

- Cursor Settings -> General -> Privacy mode
- 코드 외부 유출 방지
- 민감 코드 필터링, API 키 보호

## Model Context Protocol (MCP)

### MCP란?

Model Context Protocol(MCP)은 AI 모델이 외부 데이터 소스, 도구, 환경과 표준화된 방식으로 상호작용할 수 있도록 설계된 개방형 표준 프로토콜입니다. AI 애플리케이션을 위한 USB-C 포트와 같은 역할을 합니다.

### MCP 아키텍처

- **MCP 서버**: 특정 데이터 소스나 서비스에 연결
- **MCP 클라이언트**: AI 애플리케이션 내에서 실행
- **MCP 호스트**: Cursor IDE와 같은 AI 기반 앱
- **데이터 소스 및 서비스**: 로컬 파일, 원격 API, 클라우드 서비스 등

### MCP 활용 예시

- **데이터베이스 접근**: PostgreSQL, MySQL, MongoDB 등 연동
- **코드 저장소 연동**: Git, GitHub, GitLab 서버 통합
- **웹 검색 및 브라우징**: 구글, 빙, Brave Search 등 검색 엔진 통합
- **생산성 도구 연동**: Slack, Discord, Notion 등 통합
- **로컬 시스템 도구**: 파일 시스템 접근, 터미널 명령 실행

## 라이선스 및 가격 정책

### 무료 사용자
- AI 기능 사용 제한 (일일/월별 할당량)
- 기본 모델만 사용 가능
- 프로젝트 크기 제한

### Pro 플랜
- 무제한 AI 기능 사용
- 모든 고급 AI 모델 사용 가능 (GPT-4o, Claude 3 Opus 등)
- 우선 고객 지원

### 비즈니스 플랜
- Pro 플랜의 모든 기능 포함
- 팀 관리 기능
- 엔터프라이즈급 보안 및 규정 준수
- 전용 지원

---

이 가이드는 Cursor IDE의 기본적인 사용법과 기능을 소개합니다. 더 자세한 정보는 [공식 문서](https://cursor.sh/docs)를 참조하세요. 